@@ -1,8 +1,9 @@
 /* Traitement de certaines tables africaines.
-   Copyright  1999, 2000 Progiciels Bourbeau-Pinard inc.
-   Franois Pinard <pinard@iro.umontreal.ca>, 1997.  */
+   Copyright © 1999, 2000 Progiciels Bourbeau-Pinard inc.
+   François Pinard <pinard@iro.umontreal.ca>, 1997.  */
 
 #include "common.h"
+#include "decsteps.h"
 
 static const unsigned short ful_data[] =
   {
@@ -313,40 +314,25 @@ static const unsigned short lin_data[] =
 bool
 module_afrtran (RECODE_OUTER outer)
 {
-  if (!declare_explode_data (outer, ful_data,
-			     "AFRFUL-102-BPI_OCIL", "AFRFUL-103-BPI_OCIL"))
-    return false;
-  if (!declare_alias (outer, "t-bambara", "AFRFUL-103-BPI_OCIL"))
-    return false;
-  if (!declare_alias (outer, "t-bra", "AFRFUL-103-BPI_OCIL"))
-    return false;
-  if (!declare_alias (outer, "t-ewondo", "AFRFUL-103-BPI_OCIL"))
-    return false;
-  if (!declare_alias (outer, "t-fulfulde", "AFRFUL-103-BPI_OCIL"))
-    return false;
-  if (!declare_explode_data (outer, l1_data,
-			     "ISO-8859-1", "AFRL1-101-BPI_OCIL"))
-    return false;
-  if (!declare_alias (outer, "t-francais", "AFRL1-101-BPI_OCIL"))
-    return false;
-  if (!declare_alias (outer, "t-fra", "AFRL1-101-BPI_OCIL"))
-    return false;
-  if (!declare_explode_data (outer, lin_data,
-			     "AFRLIN-104-BPI_OCIL", "AFRLIN-105-BPI_OCIL"))
-    return false;
-  if (!declare_alias (outer, "t-lingala", "AFRLIN-105-BPI_OCIL"))
-    return false;
-  if (!declare_alias (outer, "t-lin", "AFRLIN-105-BPI_OCIL"))
-    return false;
-  if (!declare_alias (outer, "t-sango", "AFRLIN-105-BPI_OCIL"))
-    return false;
-  if (!declare_alias (outer, "t-wolof", "AFRLIN-105-BPI_OCIL"))
-    return false;
-
-  return true;
+    return declare_explode_data (outer, ful_data,
+                                 "AFRFUL-102-BPI_OCIL", "AFRFUL-103-BPI_OCIL")
+        && declare_alias (outer, "t-bambara", "AFRFUL-103-BPI_OCIL")
+        && declare_alias (outer, "t-bra", "AFRFUL-103-BPI_OCIL")
+        && declare_alias (outer, "t-ewondo", "AFRFUL-103-BPI_OCIL")
+        && declare_alias (outer, "t-fulfulde", "AFRFUL-103-BPI_OCIL")
+        && declare_explode_data (outer, l1_data,
+                                 "ISO-8859-1", "AFRL1-101-BPI_OCIL")
+        && declare_alias (outer, "t-francais", "AFRL1-101-BPI_OCIL")
+        && declare_alias (outer, "t-fra", "AFRL1-101-BPI_OCIL")
+        && declare_explode_data (outer, lin_data,
+                                 "AFRLIN-104-BPI_OCIL", "AFRLIN-105-BPI_OCIL")
+        && declare_alias (outer, "t-lingala", "AFRLIN-105-BPI_OCIL")
+        && declare_alias (outer, "t-lin", "AFRLIN-105-BPI_OCIL")
+        && declare_alias (outer, "t-sango", "AFRLIN-105-BPI_OCIL")
+        && declare_alias (outer, "t-wolof", "AFRLIN-105-BPI_OCIL");
 }
 
-void
-delmodule_afrtran (RECODE_OUTER outer)
+_GL_ATTRIBUTE_CONST void
+delmodule_afrtran (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
