@@ -1,10 +1,10 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright  1990, 93, 94, 97, 98, 99, 00 Free Software Foundation, Inc.
-   Contributed by Franois Pinard <pinard@iro.umontreal.ca>, 1988.
+   Copyright © 1990, 93, 94, 97, 98, 99, 00 Free Software Foundation, Inc.
+   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1988.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
-   as published by the Free Software Foundation; either version 2 of the
+   as published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be
@@ -13,11 +13,12 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the `recode' Library; see the file `COPYING.LIB'.
+   License along with the Recode Library; see the file `COPYING.LIB'.
    If not, write to the Free Software Foundation, Inc., 59 Temple Place -
    Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "common.h"
+#include "decsteps.h"
 
 static const char *const translation_table[256] =
   {
@@ -283,7 +284,7 @@ static const char *const translation_table[256] =
 
 static bool
 init_latin1_bangbang (RECODE_STEP step,
-		      RECODE_CONST_REQUEST request,
+		      RECODE_CONST_REQUEST request _GL_UNUSED_PARAMETER,
 		      RECODE_CONST_OPTION_LIST before_options,
 		      RECODE_CONST_OPTION_LIST after_options)
 {
@@ -390,7 +391,7 @@ module_bangbang (RECODE_OUTER outer)
 		       NULL, transform_bangbang_latin1);
 }
 
-void
-delmodule_bangbang (RECODE_OUTER outer)
+_GL_ATTRIBUTE_CONST void
+delmodule_bangbang (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
