@@ -1,10 +1,10 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright  1996, 97, 98, 99, 00 Free Software Foundation, Inc.
-   Contributed by Franois Pinard <pinard@iro.umontreal.ca>, 1996.
+   Copyright © 1996, 97, 98, 99, 00 Free Software Foundation, Inc.
+   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1996.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
-   as published by the Free Software Foundation; either version 2 of the
+   as published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be
@@ -13,11 +13,12 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the `recode' Library; see the file `COPYING.LIB'.
+   License along with the Recode Library; see the file `COPYING.LIB'.
    If not, write to the Free Software Foundation, Inc., 59 Temple Place -
    Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "common.h"
+#include "decsteps.h"
 #include "base64.h"
 
 /* Table of characters coding the 64 values.  */
@@ -97,8 +98,8 @@ transform_data_base64 (RECODE_SUBTASK subtask)
 
       /* Process first byte of a triplet.  */
 
-      put_byte (base64_value_to_char[MASK (6) & character >> 2], subtask);
-      value = (MASK (2) & character) << 4;
+      put_byte (base64_value_to_char[BIT_MASK (6) & character >> 2], subtask);
+      value = (BIT_MASK (2) & character) << 4;
 
       /* Process second byte of a triplet.  */
 
@@ -110,9 +111,9 @@ transform_data_base64 (RECODE_SUBTASK subtask)
 	  put_byte ('=', subtask);
 	  break;
 	}
-      put_byte (base64_value_to_char[value | (MASK (4) & character >> 4)],
+      put_byte (base64_value_to_char[value | (BIT_MASK (4) & character >> 4)],
 		subtask);
-      value = (MASK (4) & character) << 2;
+      value = (BIT_MASK (4) & character) << 2;
 
       /* Process third byte of a triplet.  */
 
@@ -123,9 +124,9 @@ transform_data_base64 (RECODE_SUBTASK subtask)
 	  put_byte ('=', subtask);
 	  break;
 	}
-      put_byte (base64_value_to_char[value | (MASK (2) & character >> 6)],
+      put_byte (base64_value_to_char[value | (BIT_MASK (2) & character >> 6)],
 		subtask);
-      put_byte (base64_value_to_char[MASK (6) & character], subtask);
+      put_byte (base64_value_to_char[BIT_MASK (6) & character], subtask);
     }
 
   /* Complete last partial line.  */
@@ -148,19 +149,20 @@ transform_base64_data (RECODE_SUBTASK subtask)
       /* Accept wrapping lines, reversibly if at each 76 characters.  */
 
       character = get_byte (subtask);
+
+    top:
       if (character == EOF)
-	{
-	  if (counter != 0)
-	    RETURN_IF_NOGO (RECODE_NOT_CANONICAL, subtask);
-	  SUBTASK_RETURN (subtask);
-	}
+	SUBTASK_RETURN (subtask);
 
       if (character == '\n')
 	{
+          character = get_byte (subtask);
+	  if (character == EOF)
+            SUBTASK_RETURN (subtask);
 	  if (counter != MIME_LINE_LENGTH / 4)
 	    RETURN_IF_NOGO (RECODE_NOT_CANONICAL, subtask);
 	  counter = 0;
-	  continue;
+	  goto top;
 	}
 
       if (character == '\r')
@@ -220,7 +222,7 @@ transform_base64_data (RECODE_SUBTASK subtask)
       else
 	RETURN_IF_NOGO (RECODE_INVALID_INPUT, subtask);
 
-      put_byte (MASK (8) & value >> 8, subtask);
+      put_byte (BIT_MASK (8) & value >> 8, subtask);
 
       /* Process fourth byte of a quadruplet.  */
 
@@ -239,7 +241,7 @@ transform_base64_data (RECODE_SUBTASK subtask)
       else
 	RETURN_IF_NOGO (RECODE_INVALID_INPUT, subtask);
 
-      put_byte (MASK (8) & value, subtask);
+      put_byte (BIT_MASK (8) & value, subtask);
     }
 }
 
@@ -257,7 +259,7 @@ module_base64 (RECODE_OUTER outer)
     && declare_alias (outer, "64", "Base64");
 }
 
-void
-delmodule_base64 (RECODE_OUTER outer)
+_GL_ATTRIBUTE_CONST void
+delmodule_base64 (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
