@@ -1,10 +1,10 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright  1990, 93, 94, 97, 98, 99, 00 Free Software Foundation, Inc.
-   Contributed by Franois Pinard <pinard@iro.umontreal.ca>, 1988.
+   Copyright © 1990, 93, 94, 97, 98, 99, 00 Free Software Foundation, Inc.
+   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1988.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
-   as published by the Free Software Foundation; either version 2 of the
+   as published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be
@@ -13,11 +13,12 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the `recode' Library; see the file `COPYING.LIB'.
+   License along with the Recode Library; see the file `COPYING.LIB'.
    If not, write to the Free Software Foundation, Inc., 59 Temple Place -
    Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "common.h"
+#include "decsteps.h"
 
 static const char *const translation_table[128] =
   {
@@ -173,6 +174,7 @@ init_ascii_cdcnos (RECODE_STEP step,
 
   step->step_type = RECODE_BYTE_TO_STRING;
   step->step_table = table;
+  step->step_table_term_routine = free;
   return true;
 }
 
@@ -313,6 +315,9 @@ transform_cdcnos_ascii (RECODE_SUBTASK subtask)
 		  SUBTASK_RETURN (subtask);
 	      }
 	  break;
+
+        default:
+          break;
 	}
       put_byte (input_char, subtask);
     }
@@ -332,7 +337,7 @@ module_cdcnos (RECODE_OUTER outer)
     && declare_alias (outer, "NOS", "CDC-NOS");
 }
 
-void
-delmodule_cdcnos (RECODE_OUTER outer)
+_GL_ATTRIBUTE_CONST void
+delmodule_cdcnos (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
