@@ -1,10 +1,10 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright  1990,92,93,94,96,97,98,99,00 Free Software Foundation, Inc.
-   Contributed by Franois Pinard <pinard@iro.umontreal.ca>, 1990.
+   Copyright © 1990,92,93,94,96,97,98,99,00 Free Software Foundation, Inc.
+   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1990.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
-   as published by the Free Software Foundation; either version 2 of the
+   as published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be
@@ -13,16 +13,16 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the `recode' Library; see the file `COPYING.LIB'.
+   License along with the Recode Library; see the file `COPYING.LIB'.
    If not, write to the Free Software Foundation, Inc., 59 Temple Place -
    Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "common.h"
 #include "hash.h"
 
-/* FIXME: Cleanup memory at end of job, and softly report errors.  */
+/* FIXME: Softly report errors.  */
 
-/* The satisfactory aspects are that `recode' is now able to combine a set of
+/* The satisfactory aspects are that Recode is now able to combine a set of
    sequence of UCS-2 characters into single codes, or explode those single
    codes into the original sequence.  It may happen that many sequences reduce
    to the same code, one of them is arbitrarily taken as canonical.  Any
@@ -39,7 +39,7 @@
    hash coding.
 
    The less satisfactory aspects are that the user interface is still very
-   rude.  For the time being, I merely added a "combined" charset: combining
+   crude.  For the time being, I merely added a "combined" charset: combining
    is done by `u2..co', exploding is done by `co..u2'.  We surely could do
    much better, and build on the concept of options (introduced by `+' in the
    request syntax), Options are probably going to be used for other
@@ -49,7 +49,7 @@
    foresee is that, contrarily to surfaces, options like transliteration or
    combining _require_ specific charsets (like UCS-2) as a vehicle, and if
    UCS-2 is not otherwise mandated in the request, we would have to create
-   such an UCS-2 intermediate.  On the other hand, if UCS-2 is sandwidched
+   such an UCS-2 intermediate.  On the other hand, if UCS-2 is sandwiched
    somewhere in a complex series of steps, we should implicitly propagate
    options towards the UCS-2 step.  Even if nothing looks utterly difficult, I
    guess that for doing it right, a lot of attention and care is needed.
@@ -62,10 +62,10 @@
 | Initialize for exploding.  |
 `---------------------------*/
 
-static unsigned
-combined_hash (const void *void_data, unsigned table_size)
+static size_t
+combined_hash (const void *void_data, size_t table_size)
 {
-  const unsigned short *data = void_data;
+  const unsigned short *data = (const unsigned short *) void_data;
 
   return *data % table_size;
 }
@@ -73,19 +73,19 @@ combined_hash (const void *void_data, unsigned table_size)
 static bool
 combined_compare (const void *void_first, const void *void_second)
 {
-  const unsigned short *first = void_first;
-  const unsigned short *second = void_second;
+  const unsigned short *first = (const unsigned short *) void_first;
+  const unsigned short *second = (const unsigned short *) void_second;
 
   return *first == *second;
 }
 
 bool
 init_explode (RECODE_STEP step,
-	      RECODE_CONST_REQUEST request,
+	      RECODE_CONST_REQUEST request _GL_UNUSED_PARAMETER,
 	      RECODE_CONST_OPTION_LIST before_options,
 	      RECODE_CONST_OPTION_LIST after_options)
 {
-  const unsigned short *data = step->step_table;
+  const unsigned short *data = (const unsigned short *) step->step_table;
   Hash_table *table;
 
   if (before_options || after_options)
@@ -97,6 +97,7 @@ init_explode (RECODE_STEP step,
     return false;
   step->step_type = RECODE_EXPLODE_STEP;
   step->step_table = table;
+  step->step_table_term_routine = (void (*) (void *)) hash_free;
 
   if (!data)
     return true;
@@ -121,13 +122,13 @@ init_explode (RECODE_STEP step,
 bool
 explode_byte_byte (RECODE_SUBTASK subtask)
 {
-  Hash_table *table = subtask->step->step_table;
+  Hash_table *table = (Hash_table *) subtask->step->step_table;
   unsigned value;
 
-  while (value = get_byte (subtask), value != EOF)
+  while (value = get_byte (subtask), value != (unsigned)EOF)
     {
       unsigned short lookup = value;
-      unsigned short *result = hash_lookup (table, &lookup);
+      unsigned short *result = (unsigned short *) hash_lookup (table, &lookup);
 
       if (result)
 	{
@@ -148,13 +149,13 @@ explode_byte_byte (RECODE_SUBTASK subtask)
 bool
 explode_ucs2_byte (RECODE_SUBTASK subtask)
 {
-  Hash_table *table = subtask->step->step_table;
+  Hash_table *table = (Hash_table *) subtask->step->step_table;
   unsigned value;
 
   while (get_ucs2 (&value, subtask))
     {
       unsigned short lookup = value;
-      unsigned short *result = hash_lookup (table, &lookup);
+      unsigned short *result = (unsigned short *) hash_lookup (table, &lookup);
 
       if (result)
 	{
@@ -175,10 +176,10 @@ explode_ucs2_byte (RECODE_SUBTASK subtask)
 bool
 explode_byte_ucs2 (RECODE_SUBTASK subtask)
 {
-  Hash_table *table = subtask->step->step_table;
+  Hash_table *table = (Hash_table *) subtask->step->step_table;
   unsigned value;
 
-  if (value = get_byte (subtask), value != EOF)
+  if (value = get_byte (subtask), value != (unsigned)EOF)
     {
       if (subtask->task->byte_order_mark)
 	put_ucs2 (BYTE_ORDER_MARK, subtask);
@@ -186,7 +187,8 @@ explode_byte_ucs2 (RECODE_SUBTASK subtask)
       while (true)
 	{
 	  unsigned short lookup = value;
-	  unsigned short *result = hash_lookup (table, &lookup);
+	  unsigned short *result
+            = (unsigned short *) hash_lookup (table, &lookup);
 
 	  if (result)
 	    {
@@ -197,7 +199,7 @@ explode_byte_ucs2 (RECODE_SUBTASK subtask)
 	  else
 	    put_ucs2 (value, subtask);
 
-	  if (value = get_byte (subtask), value == EOF)
+	  if (value = get_byte (subtask), value == (unsigned)EOF)
 	    break;
 	}
     }
@@ -208,7 +210,7 @@ explode_byte_ucs2 (RECODE_SUBTASK subtask)
 bool
 explode_ucs2_ucs2 (RECODE_SUBTASK subtask)
 {
-  Hash_table *table = subtask->step->step_table;
+  Hash_table *table = (Hash_table *) subtask->step->step_table;
   unsigned value;
 
   if (get_ucs2 (&value, subtask))
@@ -219,7 +221,8 @@ explode_ucs2_ucs2 (RECODE_SUBTASK subtask)
       while (true)
 	{
 	  unsigned short lookup = value;
-	  unsigned short *result = hash_lookup (table, &lookup);
+	  unsigned short *result
+            = (unsigned short *) hash_lookup (table, &lookup);
 
 	  if (result)
 	    {
@@ -262,10 +265,10 @@ struct state
 | Initialize for combining.  |
 `---------------------------*/
 
-static unsigned
-state_hash (const void *void_data, unsigned table_size)
+static size_t
+state_hash (const void *void_data, size_t table_size)
 {
-  const struct state *data = void_data;
+  const struct state *data = (const struct state *) void_data;
 
   return data->character % table_size;
 }
@@ -273,8 +276,8 @@ state_hash (const void *void_data, unsigned table_size)
 static bool
 state_compare (const void *void_first, const void *void_second)
 {
-  const struct state *first = void_first;
-  const struct state *second = void_second;
+  const struct state *first = (const struct state *) void_first;
+  const struct state *second = (const struct state *) void_second;
 
   return first->character == second->character;
 }
@@ -282,13 +285,13 @@ state_compare (const void *void_first, const void *void_second)
 static void
 state_free (void *void_state)
 {
-  struct state *state = void_state;
+  struct state *state = (struct state *) void_state;
   struct state *shift = state->shift;
 
   while (shift != NULL)
     {
       struct state *next_shift = shift->next;
-      free (shift);
+      state_free (shift);
       shift = next_shift;
     }
   free (state);
@@ -321,14 +324,14 @@ prepare_shifted_state (struct state *state, unsigned character,
     }
   else
     {
-      Hash_table *table = step->step_table;
+      Hash_table *table = (Hash_table *) step->step_table;
       struct state lookup;
 
       lookup.character = character;
-      state = hash_lookup (table, &lookup);
+      state = (struct state *) hash_lookup (table, &lookup);
       if (!state)
 	{
-	  if (state= (struct state *) malloc (sizeof (struct state)), !state)
+	  if (state = (struct state *) malloc (sizeof (struct state)), !state)
 	    return NULL;
 
 	  state->character = character;
@@ -362,21 +365,21 @@ find_shifted_state (struct state *state, unsigned character,
     }
   else
     {
-      Hash_table *table = step->step_table;
+      Hash_table *table = (Hash_table *) step->step_table;
       struct state lookup;
 
       lookup.character = character;
-      return hash_lookup (table, &lookup);
+      return (struct state *) hash_lookup (table, &lookup);
     }
 }
 
 bool
 init_combine (RECODE_STEP step,
-	      RECODE_CONST_REQUEST request,
+	      RECODE_CONST_REQUEST request _GL_UNUSED_PARAMETER,
 	      RECODE_CONST_OPTION_LIST before_options,
 	      RECODE_CONST_OPTION_LIST after_options)
 {
-  const unsigned short *data = step->step_table;
+  const unsigned short *data = (const unsigned short *) step->step_table;
   Hash_table *table;
 
   if (before_options || after_options)
@@ -388,6 +391,7 @@ init_combine (RECODE_STEP step,
     return false;
   step->step_type = RECODE_COMBINE_STEP;
   step->step_table = table;
+  step->step_table_term_routine = (void (*) (void *)) hash_free;
 
   if (!data)
     return true;
@@ -476,7 +480,7 @@ combine_byte_byte (RECODE_SUBTASK subtask)
   struct state *state = NULL;
   unsigned value;
 
-  if (value = get_byte (subtask), value != EOF)
+  if (value = get_byte (subtask), value != (unsigned)EOF)
     {
       while (true)
 	{
@@ -486,7 +490,7 @@ combine_byte_byte (RECODE_SUBTASK subtask)
 	  if (shift)
 	    {
 	      state = shift;
-	      if (value = get_byte (subtask), value == EOF)
+	      if (value = get_byte (subtask), value == (unsigned)EOF)
 		break;
 	    }
 	  else if (state)
@@ -500,7 +504,7 @@ combine_byte_byte (RECODE_SUBTASK subtask)
 	  else
 	    {
 	      put_byte (value, subtask);
-	      if (value = get_byte (subtask), value == EOF)
+	      if (value = get_byte (subtask), value == (unsigned)EOF)
 		break;
 	    }
 	}
@@ -569,7 +573,7 @@ combine_byte_ucs2 (RECODE_SUBTASK subtask)
 {
   unsigned value;
 
-  if (value = get_byte (subtask), value != EOF)
+  if (value = get_byte (subtask), value != (unsigned)EOF)
     {
       struct state *state = NULL;
 
@@ -584,7 +588,7 @@ combine_byte_ucs2 (RECODE_SUBTASK subtask)
 	  if (shift)
 	    {
 	      state = shift;
-	      if (value = get_byte (subtask), value == EOF)
+	      if (value = get_byte (subtask), value == (unsigned)EOF)
 		break;
 	    }
 	  else if (state)
@@ -598,7 +602,7 @@ combine_byte_ucs2 (RECODE_SUBTASK subtask)
 	  else
 	    {
 	      put_ucs2 (value, subtask);
-	      if (value = get_byte (subtask), value == EOF)
+	      if (value = get_byte (subtask), value == (unsigned)EOF)
 		break;
 	    }
 	}
