@@ -1,10 +1,10 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright  1997, 98, 99, 00 Free Software Foundation, Inc.
-   Contributed by Franois Pinard <pinard@iro.umontreal.ca>, 1997.
+   Copyright © 1997, 98, 99, 00 Free Software Foundation, Inc.
+   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1997.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
-   as published by the Free Software Foundation; either version 2 of the
+   as published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be
@@ -13,11 +13,12 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the `recode' Library; see the file `COPYING.LIB'.
+   License along with the Recode Library; see the file `COPYING.LIB'.
    If not, write to the Free Software Foundation, Inc., 59 Temple Place -
    Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "common.h"
+#include "decsteps.h"
 
 /* Constants for the possible bases.  If these are reordered, so should be
    the initialisers for the three tables which follow.  */
@@ -61,7 +62,7 @@ dump (RECODE_SUBTASK subtask,
 
   while (character != EOF)
     {
-      unsigned value = MASK (8) & character;
+      unsigned value = BIT_MASK (8) & character;
       unsigned byte_count;
       char buffer[14];
       const char *cursor;
@@ -71,7 +72,7 @@ dump (RECODE_SUBTASK subtask,
 	  character = get_byte (subtask);
 	  if (character == EOF)
 	    break;
-	  value = (value << 8) | (MASK (8) & character);
+	  value = (value << 8) | (BIT_MASK (8) & character);
 	}
 
       /* Write delimiters.  */
@@ -93,7 +94,10 @@ dump (RECODE_SUBTASK subtask,
 
       /* Write formatted value.  */
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-nonliteral"
       sprintf (buffer, format_table[base][byte_count], value);
+#pragma GCC diagnostic pop
       for (cursor = buffer; *cursor; cursor++)
 	put_byte (*cursor, subtask);
 
@@ -238,6 +242,9 @@ undump (RECODE_SUBTASK subtask,
 	    else
 	      break;
 	  break;
+
+        default:
+          break;
 	}
 
       if (width == 0 || width > width_table[base][expected_size])
@@ -276,13 +283,8 @@ undump (RECODE_SUBTASK subtask,
 	    size = expected_size;
 
 	  /* Produce the output bytes.  */
-
-	  {
-	    unsigned shift;
-
-	    for (shift = size * 8; shift != 0; shift -= 8)
-	      put_byte (MASK (8) & value >> (shift - 8), subtask);
-	  }
+          for (unsigned shift = size; shift != 0; shift--)
+            put_byte (BIT_MASK (8) & value >> ((shift * 8) - 8), subtask);
 	}
 
       /* Skip separators.  */
@@ -349,118 +351,90 @@ TRANSFORM (hex4_data, undump, HEXADECIMAL, 4)
 bool
 module_dump (RECODE_OUTER outer)
 {
+  return
+
   /* Single bytes.  */
 
-  if (!declare_single (outer, "data", "Octal-1",
-		       outer->quality_variable_to_variable,
-		       NULL, data_oct1))
-    return false;
-  if (!declare_single (outer, "data", "Decimal-1",
-		       outer->quality_variable_to_variable,
-		       NULL, data_dec1))
-    return false;
-  if (!declare_single (outer, "data", "Hexadecimal-1",
-		       outer->quality_variable_to_variable,
-		       NULL, data_hex1))
-    return false;
-  if (!declare_single (outer, "Octal-1", "data",
-		       outer->quality_variable_to_variable,
-		       NULL, oct1_data))
-    return false;
-  if (!declare_single (outer, "Decimal-1", "data",
-		       outer->quality_variable_to_variable,
-		       NULL, dec1_data))
-    return false;
-  if (!declare_single (outer, "Hexadecimal-1", "data",
-		       outer->quality_variable_to_variable,
-		       NULL, hex1_data))
-    return false;
+       declare_single (outer, "data", "Octal-1",
+                       outer->quality_variable_to_variable,
+                       NULL, data_oct1)
+    && declare_single (outer, "data", "Decimal-1",
+                       outer->quality_variable_to_variable,
+                       NULL, data_dec1)
+    && declare_single (outer, "data", "Hexadecimal-1",
+                       outer->quality_variable_to_variable,
+                       NULL, data_hex1)
+    && declare_single (outer, "Octal-1", "data",
+                       outer->quality_variable_to_variable,
+                       NULL, oct1_data)
+    && declare_single (outer, "Decimal-1", "data",
+                       outer->quality_variable_to_variable,
+                       NULL, dec1_data)
+    && declare_single (outer, "Hexadecimal-1", "data",
+                       outer->quality_variable_to_variable,
+                       NULL, hex1_data)
 
-  if (!declare_alias (outer, "o1", "Octal-1"))
-    return false;
-  if (!declare_alias (outer, "d1", "Decimal-1"))
-    return false;
-  if (!declare_alias (outer, "x1", "Hexadecimal-1"))
-    return false;
-  if (!declare_alias (outer, "o", "Octal-1"))
-    return false;
-  if (!declare_alias (outer, "d", "Decimal-1"))
-    return false;
-  if (!declare_alias (outer, "x", "Hexadecimal-1"))
-    return false;
+    && declare_alias (outer, "o1", "Octal-1")
+    && declare_alias (outer, "d1", "Decimal-1")
+    && declare_alias (outer, "x1", "Hexadecimal-1")
+    && declare_alias (outer, "o", "Octal-1")
+    && declare_alias (outer, "d", "Decimal-1")
+    && declare_alias (outer, "x", "Hexadecimal-1")
 
   /* Double bytes.  */
 
-  if (!declare_single (outer, "data", "Octal-2",
+    && declare_single (outer, "data", "Octal-2",
 		       outer->quality_variable_to_variable,
-		       NULL, data_oct2))
-    return false;
-  if (!declare_single (outer, "data", "Decimal-2",
+		       NULL, data_oct2)
+    && declare_single (outer, "data", "Decimal-2",
 		       outer->quality_variable_to_variable,
-		       NULL, data_dec2))
-    return false;
-  if (!declare_single (outer, "data", "Hexadecimal-2",
+		       NULL, data_dec2)
+    && declare_single (outer, "data", "Hexadecimal-2",
 		       outer->quality_variable_to_variable,
-		       NULL, data_hex2))
-    return false;
-  if (!declare_single (outer, "Octal-2", "data",
+		       NULL, data_hex2)
+    && declare_single (outer, "Octal-2", "data",
 		       outer->quality_variable_to_variable,
-		       NULL, oct2_data))
-    return false;
-  if (!declare_single (outer, "Decimal-2", "data",
+		       NULL, oct2_data)
+    && declare_single (outer, "Decimal-2", "data",
 		       outer->quality_variable_to_variable,
-		       NULL, dec2_data))
-    return false;
-  if (!declare_single (outer, "Hexadecimal-2", "data",
+		       NULL, dec2_data)
+    && declare_single (outer, "Hexadecimal-2", "data",
 		       outer->quality_variable_to_variable,
-		       NULL, hex2_data))
-    return false;
+		       NULL, hex2_data)
 
-  if (!declare_alias (outer, "o2", "Octal-2"))
-    return false;
-  if (!declare_alias (outer, "d2", "Decimal-2"))
-    return false;
-  if (!declare_alias (outer, "x2", "Hexadecimal-2"))
-    return false;
+    && declare_alias (outer, "o2", "Octal-2")
+    && declare_alias (outer, "d2", "Decimal-2")
+    && declare_alias (outer, "x2", "Hexadecimal-2")
 
   /* Quadruple bytes.  */
 
-  if (!declare_single (outer, "data", "Octal-4",
+    && declare_single (outer, "data", "Octal-4",
 		       outer->quality_variable_to_variable,
-		       NULL, data_oct4))
-    return false;
-  if (!declare_single (outer, "data", "Decimal-4",
+		       NULL, data_oct4)
+    && declare_single (outer, "data", "Decimal-4",
 		       outer->quality_variable_to_variable,
-		       NULL, data_dec4))
-    return false;
-  if (!declare_single (outer, "data", "Hexadecimal-4",
+		       NULL, data_dec4)
+    && declare_single (outer, "data", "Hexadecimal-4",
 		       outer->quality_variable_to_variable,
-		       NULL, data_hex4))
-    return false;
-  if (!declare_single (outer, "Octal-4", "data",
+		       NULL, data_hex4)
+    && declare_single (outer, "Octal-4", "data",
 		       outer->quality_variable_to_variable,
-		       NULL, oct4_data))
-    return false;
-  if (!declare_single (outer, "Decimal-4", "data",
+		       NULL, oct4_data)
+    && declare_single (outer, "Decimal-4", "data",
 		       outer->quality_variable_to_variable,
-		       NULL, dec4_data))
-    return false;
-  if (!declare_single (outer, "Hexadecimal-4", "data",
+		       NULL, dec4_data)
+    && declare_single (outer, "Hexadecimal-4", "data",
 		       outer->quality_variable_to_variable,
-		       NULL, hex4_data))
-    return false;
+		       NULL, hex4_data)
 
-  if (!declare_alias (outer, "o4", "Octal-4"))
-    return false;
-  if (!declare_alias (outer, "d4", "Decimal-4"))
-    return false;
-  if (!declare_alias (outer, "x4", "Hexadecimal-4"))
-    return false;
+    && declare_alias (outer, "o4", "Octal-4")
+    && declare_alias (outer, "d4", "Decimal-4")
+    && declare_alias (outer, "x4", "Hexadecimal-4")
 
-  return true;
+    ;
 }
 
-void
-delmodule_dump (RECODE_OUTER outer)
+_GL_ATTRIBUTE_CONST void
+delmodule_dump (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
