@@ -1,10 +1,10 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright  1990, 93, 97, 98, 99, 00 Free Software Foundation, Inc.
-   Contributed by Franois Pinard <pinard@iro.umontreal.ca>, 1988.
+   Copyright © 1990, 93, 97, 98, 99, 00 Free Software Foundation, Inc.
+   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1988.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
-   as published by the Free Software Foundation; either version 2 of the
+   as published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be
@@ -13,7 +13,7 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the `recode' Library; see the file `COPYING.LIB'.
+   License along with the Recode Library; see the file `COPYING.LIB'.
    If not, write to the Free Software Foundation, Inc., 59 Temple Place -
    Suite 330, Boston, MA 02111-1307, USA.  */
 
@@ -21,6 +21,7 @@
 /* Previously: #define ASCII "ASCII-BS" */
 
 #include "common.h"
+#include "decsteps.h"
 
 static unsigned char const ascii_to_ebcdic[256] =
   {
@@ -137,7 +138,7 @@ static unsigned char const ascii_to_ebcdic_ibm[256] =
 
 static bool
 init_ascii_ebcdic (RECODE_STEP step,
-		   RECODE_CONST_REQUEST request,
+		   RECODE_CONST_REQUEST request _GL_UNUSED_PARAMETER,
 		   RECODE_CONST_OPTION_LIST before_options,
 		   RECODE_CONST_OPTION_LIST after_options)
 {
@@ -163,6 +164,7 @@ init_ebcdic_ascii (RECODE_STEP step,
       step->step_table)
     {
       step->step_type = RECODE_BYTE_TO_BYTE;
+      step->step_table_term_routine = free;
       return true;
     }
   else
@@ -171,7 +173,7 @@ init_ebcdic_ascii (RECODE_STEP step,
 
 static bool
 init_ascii_ebcdic_ccc (RECODE_STEP step,
-		       RECODE_CONST_REQUEST request,
+		       RECODE_CONST_REQUEST request _GL_UNUSED_PARAMETER,
 		       RECODE_CONST_OPTION_LIST before_options,
 		       RECODE_CONST_OPTION_LIST after_options)
 {
@@ -198,6 +200,7 @@ init_ebcdic_ccc_ascii (RECODE_STEP step,
       step->step_table)
     {
       step->step_type = RECODE_BYTE_TO_BYTE;
+      step->step_table_term_routine = free;
       return true;
     }
   else
@@ -206,7 +209,7 @@ init_ebcdic_ccc_ascii (RECODE_STEP step,
 
 static bool
 init_ascii_ebcdic_ibm (RECODE_STEP step,
-		       RECODE_CONST_REQUEST request,
+		       RECODE_CONST_REQUEST request _GL_UNUSED_PARAMETER,
 		       RECODE_CONST_OPTION_LIST before_options,
 		       RECODE_CONST_OPTION_LIST after_options)
 {
@@ -232,6 +235,7 @@ init_ebcdic_ibm_ascii (RECODE_STEP step,
       step->step_table)
     {
       step->step_type = RECODE_BYTE_TO_BYTE;
+      step->step_table_term_routine = free;
       return true;
     }
   else
@@ -262,7 +266,7 @@ module_ebcdic (RECODE_OUTER outer)
 		       init_ebcdic_ibm_ascii, transform_byte_to_byte);
 }
 
-void
-delmodule_ebcdic (RECODE_OUTER outer)
+_GL_ATTRIBUTE_CONST void
+delmodule_ebcdic (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
