@@ -1,10 +1,10 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright  1990, 93, 94, 97, 98, 99, 00 Free Software Foundation, Inc.
-   Contributed by Franois Pinard <pinard@iro.umontreal.ca>, 1988.
+   Copyright © 1990, 93, 94, 97, 98, 99, 00 Free Software Foundation, Inc.
+   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1988.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
-   as published by the Free Software Foundation; either version 2 of the
+   as published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be
@@ -13,11 +13,12 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the `recode' Library; see the file `COPYING.LIB'.
+   License along with the Recode Library; see the file `COPYING.LIB'.
    If not, write to the Free Software Foundation, Inc., 59 Temple Place -
    Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "common.h"
+#include "decsteps.h"
 
 static bool
 transform_ascii_flat (RECODE_SUBTASK subtask)
@@ -84,9 +85,9 @@ transform_ascii_flat (RECODE_SUBTASK subtask)
 	    RETURN_IF_NOGO (RECODE_AMBIGUOUS_OUTPUT, subtask);
 	    put_byte ('M', subtask);
 	    put_byte ('-', subtask);
-	    input_char &= MASK (7);
+	    input_char &= BIT_MASK (7);
 	  }
-	if (input_char < ' ' || input_char == MASK (7))
+	if (input_char < ' ' || input_char == BIT_MASK (7))
 	  {
 	    RETURN_IF_NOGO (RECODE_AMBIGUOUS_OUTPUT, subtask);
 	    put_byte ('^', subtask);
@@ -108,7 +109,7 @@ module_flat (RECODE_OUTER outer)
   return true;
 }
 
-void
-delmodule_flat (RECODE_OUTER outer)
+_GL_ATTRIBUTE_CONST void
+delmodule_flat (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
