@@ -1,10 +1,10 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright  1990, 93, 97, 98, 99, 00 Free Software Foundation, Inc.
-   Contributed by Franois Pinard <pinard@iro.umontreal.ca>, 1988.
+   Copyright © 1990, 93, 97, 98, 99, 00 Free Software Foundation, Inc.
+   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1988.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
-   as published by the Free Software Foundation; either version 2 of the
+   as published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be
@@ -13,11 +13,12 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the `recode' Library; see the file `COPYING.LIB'.
+   License along with the Recode Library; see the file `COPYING.LIB'.
    If not, write to the Free Software Foundation, Inc., 59 Temple Place -
    Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "common.h"
+#include "decsteps.h"
 #include "hash.h"
 
 /* FIXME: An @code{HTML} text which has spurious semi-colons to end entities
@@ -27,7 +28,7 @@
 /* Tables.  */
 
 /* The following entities, said to be from Emacs-w3, are ignored for the
-   time being, as recode is not too fond on graphical approximations:
+   time being, as recode is not too fond of graphical approximations:
 
 	&ensp;          \
 	&emsp;          \ \
@@ -381,16 +382,16 @@ static struct ucs2_to_string translations [] =
 
 #undef ENTRY
 
-/* UCS-2 towards HTML.  */
+/* UCS-2 to HTML.  */
 
 /*-------------------------------------.
 | Return hash value given TABLE_SIZE.  |
 `-------------------------------------*/
 
-static unsigned
-code_hash (const void *void_data, unsigned table_size)
+static size_t
+code_hash (const void *void_data, size_t table_size)
 {
-  struct ucs2_to_string const *data = void_data;
+  struct ucs2_to_string const *data = (struct ucs2_to_string const *) void_data;
 
   return data->code % table_size;
 }
@@ -402,8 +403,10 @@ code_hash (const void *void_data, unsigned table_size)
 static bool
 code_compare (const void *void_first, const void *void_second)
 {
-  struct ucs2_to_string const *first = void_first;
-  struct ucs2_to_string const *second = void_second;
+  struct ucs2_to_string const *first
+    = (struct ucs2_to_string const *) void_first;
+  struct ucs2_to_string const *second
+    = (struct ucs2_to_string const *) void_second;
 
   return first->code == second->code;
 }
@@ -433,10 +436,14 @@ init_ucs2_html (RECODE_STEP step,
     if (cursor->flags & mask
 	&& (!request->diacritics_only || cursor->code > 128))
       if (!hash_insert (table, cursor))
-	return false;
+	{
+	  hash_free (table);
+	  return false;
+	}
 
   step->step_type = RECODE_UCS2_TO_STRING;
   step->step_table = table;
+  step->step_table_term_routine = (void (*) (void *)) hash_free;
   return true;
 }
 
@@ -507,7 +514,7 @@ init_ucs2_html_v40 (RECODE_STEP step,
 static bool
 transform_ucs2_html (RECODE_SUBTASK subtask)
 {
-  Hash_table *table = subtask->step->step_table;
+  Hash_table *table = (Hash_table *) subtask->step->step_table;
   unsigned value;
 
   while (get_ucs2 (&value, subtask))
@@ -516,7 +523,7 @@ transform_ucs2_html (RECODE_SUBTASK subtask)
       struct ucs2_to_string *entry;
 
       lookup.code = value;
-      entry = hash_lookup (table, &lookup);
+      entry = (struct ucs2_to_string *) hash_lookup (table, &lookup);
       if (entry)
 	{
 	  const char *cursor = entry->string;
@@ -553,7 +560,7 @@ transform_ucs2_html (RECODE_SUBTASK subtask)
   SUBTASK_RETURN (subtask);
 }
 
-/* HTML towards UCS-2.  */
+/* HTML to UCS-2.  */
 
 #define ENTITY_BUFFER_LENGTH 20
 
@@ -568,10 +575,10 @@ transform_ucs2_html (RECODE_SUBTASK subtask)
 | Return hash value given TABLE_SIZE.  |
 `-------------------------------------*/
 
-static unsigned
-string_hash (const void *void_data, unsigned table_size)
+static size_t
+string_hash (const void *void_data, size_t table_size)
 {
-  struct ucs2_to_string const *data = void_data;
+  struct ucs2_to_string const *data = (struct ucs2_to_string const *) void_data;
 
   return hash_string (data->string, table_size);
 }
@@ -583,8 +590,8 @@ string_hash (const void *void_data, unsigned table_size)
 static bool
 string_compare (const void *void_first, const void *void_second)
 {
-  struct ucs2_to_string const *first = void_first;
-  struct ucs2_to_string const *second = void_second;
+  struct ucs2_to_string const *first = (struct ucs2_to_string const *) void_first;
+  struct ucs2_to_string const *second = (struct ucs2_to_string const *) void_second;
 
   return strcmp (first->string, second->string) == 0;
 }
@@ -614,10 +621,14 @@ init_html_ucs2 (RECODE_STEP step,
     if (cursor->flags & mask
 	&& (!request->diacritics_only || cursor->code > 128))
       if (!hash_insert (table, cursor))
-	return false;
+	{
+	  hash_free (table);
+	  return false;
+	}
 
   step->step_type = RECODE_STRING_TO_UCS2;
   step->step_table = table;
+  step->step_table_term_routine = (void (*) (void *)) hash_free;
   return true;
 }
 
@@ -695,6 +706,12 @@ transform_html_ucs2 (RECODE_SUBTASK subtask)
   if (input_char != EOF)
     put_ucs2 (BYTE_ORDER_MARK, subtask);	/* FIXME: experimental */
 
+  /* According to RFC 2718 and the Unicode Standard, if you declare the
+     character encoding of your page using HTTP as either "UTF-16LE" or
+     "UTF-16BE" then you should not use a byte-order mark at the beginning
+     of the page. Only if the page is labelled in HTTP using IANA charset
+     name "UTF-16" is a byte-order mark appropriate.  */
+
   while (input_char != EOF)
 
     if (input_char == '&')
@@ -825,7 +842,8 @@ transform_html_ucs2 (RECODE_SUBTASK subtask)
 		struct ucs2_to_string *entry;
 
 		lookup.string = buffer;
-		entry = hash_lookup (subtask->step->step_table, &lookup);
+		entry = (struct ucs2_to_string *) hash_lookup
+		  ((const Hash_table *) subtask->step->step_table, &lookup);
 		if (entry)
 		  {
 		    put_ucs2 (entry->code, subtask);
@@ -909,7 +927,7 @@ module_html (RECODE_OUTER outer)
     && declare_alias (outer, "h", "HTML_4.0");
 }
 
-void
-delmodule_html (RECODE_OUTER outer)
+_GL_ATTRIBUTE_CONST void
+delmodule_html (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
