@@ -1,10 +1,10 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright  1990, 93, 94, 97, 98, 99, 00 Free Software Foundation, Inc.
-   Contributed by Franois Pinard <pinard@iro.umontreal.ca>, 1988.
+   Copyright © 1990, 93, 94, 97, 98, 99, 00 Free Software Foundation, Inc.
+   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1988.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
-   as published by the Free Software Foundation; either version 2 of the
+   as published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be
@@ -13,11 +13,12 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the `recode' Library; see the file `COPYING.LIB'.
+   License along with the Recode Library; see the file `COPYING.LIB'.
    If not, write to the Free Software Foundation, Inc., 59 Temple Place -
    Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "common.h"
+#include "decsteps.h"
 
 /* Previously, the CR-LF surface was built-in.  It is now handled through a
    separate, optional step.  An optimisation might use a flag to trigger old
@@ -164,14 +165,16 @@ static struct recode_known_pair known_pairs[] =
 
     {255, 160},			/* no-break space */
   };
-#define NUMBER_OF_PAIRS (sizeof (known_pairs) / sizeof (struct recode_known_pair))
+#define NUMBER_OF_PAIRS \
+  (sizeof (known_pairs) / sizeof (struct recode_known_pair))
 
 static bool
 transform_latin1_ibmpc (RECODE_SUBTASK subtask)
 {
   if (subtask->step->fallback_routine == reversibility)
     {
-      const unsigned char *table = subtask->step->step_table;
+      const unsigned char *table
+	= (const unsigned char *) subtask->step->step_table;
       int input_char;
 
       while (input_char = get_byte (subtask), input_char != EOF)
@@ -185,7 +188,8 @@ transform_latin1_ibmpc (RECODE_SUBTASK subtask)
     }
   else
     {
-      const char *const *table = subtask->step->step_table;
+      const char *const *table
+	= (const char *const *) subtask->step->step_table;
       int input_char;
 
       while (input_char = get_byte (subtask), input_char != EOF)
@@ -207,7 +211,8 @@ transform_ibmpc_latin1 (RECODE_SUBTASK subtask)
 {
   if (subtask->step->fallback_routine == reversibility)
     {
-      const unsigned char *table = subtask->step->step_table;
+      const unsigned char *table
+	= (const unsigned char *) subtask->step->step_table;
       int input_char = get_byte (subtask);
 
       while (input_char != EOF)
@@ -231,7 +236,7 @@ transform_ibmpc_latin1 (RECODE_SUBTASK subtask)
 
 	  case DOS_LF:
 	    RETURN_IF_NOGO (RECODE_AMBIGUOUS_OUTPUT, subtask);
-	    /* Fall through.  */
+	    FALLTHROUGH;
 
 	  default:
 	    put_byte (table[input_char], subtask);
@@ -240,7 +245,8 @@ transform_ibmpc_latin1 (RECODE_SUBTASK subtask)
     }
   else
     {
-      const char *const *table = subtask->step->step_table;
+      const char *const *table
+	= (const char *const *) subtask->step->step_table;
       int input_char = get_byte (subtask);
 
       while (input_char != EOF)
@@ -266,7 +272,7 @@ transform_ibmpc_latin1 (RECODE_SUBTASK subtask)
 
 	  case DOS_LF:
 	    RETURN_IF_NOGO (RECODE_AMBIGUOUS_OUTPUT, subtask);
-	    /* Fall through.  */
+	    FALLTHROUGH;
 
 	  default:
 	    if (table[input_char])
@@ -375,15 +381,11 @@ module_ibmpc (RECODE_OUTER outer)
     return false;
   if (!declare_implied_surface (outer, alias, outer->crlf_surface))
     return false;
-#if 0
-  /* FIXME!  */
-  if (!declare_alias (outer, "IBM-PC", "ibm437"))
-    return false;
-#endif
+
   return true;
 }
 
-void
-delmodule_ibmpc (RECODE_OUTER outer)
+_GL_ATTRIBUTE_CONST void
+delmodule_ibmpc (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
