@@ -237,7 +237,7 @@ Operation modes:\n\
       fputs (_("\
 \n\
 Fine tuning:\n\
-  -s, --strict           use strict mappings, even loose characters\n\
+  -s, --strict           use strict mappings; discard untranslatable characters\n\
   -d, --diacritics       convert only diacritics or alike for HTML/LaTeX/BibTeX\n\
   -S, --source[=LN]      limit recoding to strings and comments as for LN\n\
   -c, --colons           use colons instead of double quotes for diaeresis\n\
@@ -279,7 +279,7 @@ FILE is specified, then act as a filter and recode stdin to stdout.\n"),
 	     stdout);
       fputs (_("\
 \n\
-Report bugs at https://github.com/rrthomas/Recode\n"),
+Report bugs at https://github.com/rrthomas/recode\n"),
 	       stdout);
     }
   exit (status);
@@ -575,7 +575,7 @@ Written by François Pinard <pinard@iro.umontreal.ca>.\n"),
 	     stdout);
       fputs (_("\
 \n\
-Copyright (C) 1990, 92-94, 96, 97, 99, 08 Free Software Foundation, Inc.\n"),
+Copyright (C) 1990-2018 Free Software Foundation, Inc.\n"),
 	     stdout);
       fputs (_("\
 This is free software; see the source for copying conditions.  There is NO\n\
