@@ -1,10 +1,10 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright  1990,92,93,94,96,97,98,99,00 Free Software Foundation, Inc.
-   Franois Pinard <pinard@iro.umontreal.ca>, 1990.
+   Copyright © 1990,92,93,94,96,97,98,99,00 Free Software Foundation, Inc.
+   François Pinard <pinard@iro.umontreal.ca>, 1990.
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
-   Free Software Foundation; either version 2, or (at your option) any later
+   Free Software Foundation; either version 3, or (at your option) any later
    version.
 
    This program is distributed in the hope that it will be useful, but
@@ -40,14 +40,13 @@ open_mixed (struct mixed *mixed, RECODE_TASK task)
 {
   mixed->input_name = task->input.name;
   mixed->output_name = task->output.name;
-  task->strategy = RECODE_SEQUENCE_IN_MEMORY;
   task->byte_order_mark = false;
 
   /* Open both files ourselves.  */
 
   if (!*(task->input.name))
     task->input.file = stdin;
-  else if (task->input.file = fopen (mixed->input_name, "r"),
+  else if (task->input.file = fopen (mixed->input_name, "rb"),
 	   !task->input.file)
     {
       recode_perror (NULL, "fopen (%s)", task->input.name);
@@ -57,12 +56,11 @@ open_mixed (struct mixed *mixed, RECODE_TASK task)
 
   if (!*(task->output.name))
     task->output.file = stdout;
-  else if (task->output.file = fopen (mixed->output_name, "w"),
+  else if (task->output.file = fopen (mixed->output_name, "wb"),
 	   !task->output.file)
     {
       recode_perror (NULL, "fopen (%s)", task->output.name);
-      if (*(task->input.name))
-	fclose (task->input.file);
+      fclose (task->input.file);
       return false;
     }
   task->output.name = NULL;
@@ -78,25 +76,28 @@ open_mixed (struct mixed *mixed, RECODE_TASK task)
   return true;
 }
 
-static void
+static bool
 close_mixed (struct mixed *mixed)
 {
   /* Clean up.  */
 
-  if (*(mixed->input_name))
-    fclose (mixed->subtask.task->input.file);
-  if (*(mixed->output_name))
-    fclose (mixed->subtask.task->output.file);
+  if (mixed->subtask.task->input.file
+      && fclose (mixed->subtask.task->input.file) != 0)
+    return false;
+  if (mixed->subtask.task->output.file
+      && fclose (mixed->subtask.task->output.file))
+    return false;
+  return true;
 }
 
-static /*inline*/ void
+static void
 start_accumulation (struct mixed *mixed)
 {
   mixed->buffer.cursor = mixed->buffer.buffer;
   mixed->subtask.output = mixed->buffer;
 }
 
-static /*inline*/ bool
+static bool
 recode_accumulated (struct mixed *mixed)
 {
   RECODE_TASK task = mixed->subtask.task;
@@ -125,70 +126,27 @@ bool
 transform_c_source (RECODE_TASK task)
 {
   struct mixed mixed;
-  bool status = true;
   int character;
 
   if (!open_mixed (&mixed, task))
-    return false;
-
-  character = get_byte (&mixed.subtask);
-  while (character != EOF)
-    switch (character)
-      {
-      case '\'':
-	/* Skip character constant, while copying it untranslated.  */
-
-	put_byte ('\'', &mixed.subtask);
-	character = get_byte (&mixed.subtask);
-
-	if (character == EOF)
+    recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
+  else
+    {
+      character = get_byte (&mixed.subtask);
+      while (character != EOF)
+	switch (character)
 	  {
-	    status = false;
-	    break;
-	  }
+	  case '\'':
+	    /* Skip character constant, while copying it untranslated.  */
 
-	if (character == '\\')
-	  {
-	    put_byte ('\\', &mixed.subtask);
-	    character = get_byte (&mixed.subtask);
-	    if (character == EOF)
-	      {
-		status = false;
-		break;
-	      }
-	    put_byte (character, &mixed.subtask);
-	    character = get_byte (&mixed.subtask);
-	  }
-
-	if (character == '\'')
-	  {
 	    put_byte ('\'', &mixed.subtask);
 	    character = get_byte (&mixed.subtask);
-	  }
-	else
-	  status = false;
-	break;
 
-      case '"':
-	/* Copy the string, translated.  */
-
-	put_byte ('"', &mixed.subtask);
-	character = get_byte (&mixed.subtask);
-
-	/* Read in string.  */
-
-	start_accumulation (&mixed);
-
-	while (true)
-	  {
 	    if (character == EOF)
 	      {
-		recode_accumulated (&mixed);
-		status = false;
+		recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
 		break;
 	      }
-	    if (character == '"')
-	      break;
 
 	    if (character == '\\')
 	      {
@@ -196,97 +154,142 @@ transform_c_source (RECODE_TASK task)
 		character = get_byte (&mixed.subtask);
 		if (character == EOF)
 		  {
-		    recode_accumulated (&mixed);
-		    status = false;
+		    recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
 		    break;
 		  }
+		put_byte (character, &mixed.subtask);
+		character = get_byte (&mixed.subtask);
 	      }
-	    put_byte (character, &mixed.subtask);
-	    character = get_byte (&mixed.subtask);
-	  }
-	if (character == EOF)
-	  break;
 
-	/* Translate string and dump it.  */
+	    if (character == '\'')
+	      {
+		put_byte ('\'', &mixed.subtask);
+		character = get_byte (&mixed.subtask);
+	      }
+	    else
+	      recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
+	    break;
 
-	if (!recode_accumulated (&mixed))
-	  status = false;
-	put_byte ('"', &mixed.subtask);
-	character = get_byte (&mixed.subtask);
-	break;
+	  case '"':
+	    /* Copy the string, translated.  */
 
-      case '/':
-	put_byte ('/', &mixed.subtask);
-	character = get_byte (&mixed.subtask);
-	if (character == EOF)
-	  break;
-	if (character == '*')
-	  {
-	    /* Copy the comment, translated.  */
-
-	    put_byte ('*', &mixed.subtask);
+	    put_byte ('"', &mixed.subtask);
 	    character = get_byte (&mixed.subtask);
 
-	    /* Read in comment.  */
+	    /* Read in string.  */
 
 	    start_accumulation (&mixed);
+
 	    while (true)
 	      {
 		if (character == EOF)
 		  {
 		    recode_accumulated (&mixed);
-		    status = false;
+		    recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
 		    break;
 		  }
-		if (character == '*')
+		if (character == '"')
+		  break;
+
+		if (character == '\\')
 		  {
+		    put_byte ('\\', &mixed.subtask);
 		    character = get_byte (&mixed.subtask);
 		    if (character == EOF)
 		      {
 			recode_accumulated (&mixed);
-			status = false;
-			put_byte ('*', &mixed.subtask);
+			recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
 			break;
 		      }
-		    if (character == '/')
-		      break;
-		    put_byte ('*', &mixed.subtask);
-		  }
-		else
-		  {
-		    put_byte (character, &mixed.subtask);
-		    character = get_byte (&mixed.subtask);
 		  }
+		put_byte (character, &mixed.subtask);
+		character = get_byte (&mixed.subtask);
 	      }
-
 	    if (character == EOF)
 	      break;
 
-	    /* Translate comment and dump it.  */
+	    /* Translate string and dump it.  */
 
 	    if (!recode_accumulated (&mixed))
-	      status = false;
-	    put_byte ('*', &mixed.subtask);
+	      recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
+	    put_byte ('"', &mixed.subtask);
+	    character = get_byte (&mixed.subtask);
+	    break;
+
+	  case '/':
 	    put_byte ('/', &mixed.subtask);
 	    character = get_byte (&mixed.subtask);
+	    if (character == EOF)
+	      break;
+	    if (character == '*')
+	      {
+		/* Copy the comment, translated.  */
+
+		put_byte ('*', &mixed.subtask);
+		character = get_byte (&mixed.subtask);
+
+		/* Read in comment.  */
+
+		start_accumulation (&mixed);
+		while (true)
+		  {
+		    if (character == EOF)
+		      {
+			recode_accumulated (&mixed);
+			recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
+			break;
+		      }
+		    if (character == '*')
+		      {
+			character = get_byte (&mixed.subtask);
+			if (character == EOF)
+			  {
+			    recode_accumulated (&mixed);
+			    recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
+			    put_byte ('*', &mixed.subtask);
+			    break;
+			  }
+			if (character == '/')
+			  break;
+			put_byte ('*', &mixed.subtask);
+		      }
+		    else
+		      {
+			put_byte (character, &mixed.subtask);
+			character = get_byte (&mixed.subtask);
+		      }
+		  }
+
+		if (character == EOF)
+		  break;
+
+		/* Translate comment and dump it.  */
+
+		if (!recode_accumulated (&mixed))
+		  recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
+		put_byte ('*', &mixed.subtask);
+		put_byte ('/', &mixed.subtask);
+		character = get_byte (&mixed.subtask);
+	      }
+	    break;
+
+	  default:
+	    put_byte (character, &mixed.subtask);
+	    character = get_byte (&mixed.subtask);
+	    break;
 	  }
-	break;
+    }
 
-      default:
-	put_byte (character, &mixed.subtask);
-	character = get_byte (&mixed.subtask);
-	break;
-      }
-
-  close_mixed (&mixed);
-  return status;
+  if (!close_mixed (&mixed))
+    recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
+  SUBTASK_RETURN (&mixed.subtask);
 }
 
 /*------------------------------------------------------------------------.
 | Transform only strings or comments in an PO source, expected in ASCII.  |
 `------------------------------------------------------------------------*/
 
-/* There is a limitation to -Spo: if `recode' converts some `msgstr' in a way
+/* There is a limitation to -Spo: if Recode converts some `msgstr' in a way
    that might produce quotes (or backslashes), these should then be requoted.
    Doing this would then also require to fully unquote the original `msgstr'
    string.  But it seems that such a need does not occur in most cases I can
@@ -298,140 +301,135 @@ bool
 transform_po_source (RECODE_TASK task)
 {
   struct mixed mixed;
-  bool status = true;
   bool recode = false;
   bool msgstr = false;
-  int character;
 
   if (!open_mixed (&mixed, task))
-    return false;
-
-  character = get_byte (&mixed.subtask);
-  while (character != EOF)
-    switch (character)
-      {
-      case '#':
-	/* Copy a comment, recoding only those written by translators.  */
-
-	put_byte ('#', &mixed.subtask);
-	character = get_byte (&mixed.subtask);
-	if (character == EOF)
-	  break;
-	recode = character == ' ' || character == '\t';
-
-	if (recode)
-	  start_accumulation (&mixed);
-
-	while (character != '\n' && character != EOF)
+    recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
+  else
+    {
+      int character = get_byte (&mixed.subtask);
+      while (character != EOF)
+	switch (character)
 	  {
-	    put_byte (character, &mixed.subtask);
+	  case '#':
+	    /* Copy a comment, recoding only those written by translators.  */
+
+	    put_byte ('#', &mixed.subtask);
 	    character = get_byte (&mixed.subtask);
-	  }
-
-	if (recode)
-	  {
-	    if (!recode_accumulated (&mixed))
-	      status = false;
-	  }
-
-	if (character == EOF)
-	  break;
-	put_byte ('\n', &mixed.subtask);
-	character = get_byte (&mixed.subtask);
-	break;
-
-      case 'm':
-	/* Attempt to recognise `msgstr'.  */
-
-	msgstr = false;
-
-	put_byte ('m', &mixed.subtask);
-	character = get_byte (&mixed.subtask);
-	if (character != 's')
-	  break;
-	put_byte ('s', &mixed.subtask);
-	character = get_byte (&mixed.subtask);
-	if (character != 'g')
-	  break;
-	put_byte ('g', &mixed.subtask);
-	character = get_byte (&mixed.subtask);
-	if (character != 's')
-	  break;
-	put_byte ('s', &mixed.subtask);
-	character = get_byte (&mixed.subtask);
-	if (character != 't')
-	  break;
-	put_byte ('t', &mixed.subtask);
-	character = get_byte (&mixed.subtask);
-	if (character != 'r')
-	  break;
-	put_byte ('r', &mixed.subtask);
-	character = get_byte (&mixed.subtask);
-
-	msgstr = true;
-	break;
-
-      case '"':
-	/* Copy the string, translating only the `msgstr' ones.  */
-
-	put_byte ('"', &mixed.subtask);
-	character = get_byte (&mixed.subtask);
-	recode = msgstr;
-
-	if (recode)
-	  start_accumulation (&mixed);
-
-	while (true)
-	  {
 	    if (character == EOF)
-	      {
-		if (recode)
-		  {
-		    recode_accumulated (&mixed);
-		    status = false;
-		  }
-		break;
-	      }
-	    if (character == '"')
 	      break;
+	    recode = character == ' ' || character == '\t';
 
-	    if (character == '\\')
+	    if (recode)
+	      start_accumulation (&mixed);
+
+	    while (character != '\n' && character != EOF)
 	      {
-		put_byte ('\\', &mixed.subtask);
+		put_byte (character, &mixed.subtask);
 		character = get_byte (&mixed.subtask);
+	      }
+
+	    if (recode && !recode_accumulated (&mixed))
+	      recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
+
+	    if (character == EOF)
+	      break;
+	    put_byte ('\n', &mixed.subtask);
+	    character = get_byte (&mixed.subtask);
+	    break;
+
+	  case 'm':
+	    /* Attempt to recognise `msgstr'.  */
+
+	    msgstr = false;
+
+	    put_byte ('m', &mixed.subtask);
+	    character = get_byte (&mixed.subtask);
+	    if (character != 's')
+	      break;
+	    put_byte ('s', &mixed.subtask);
+	    character = get_byte (&mixed.subtask);
+	    if (character != 'g')
+	      break;
+	    put_byte ('g', &mixed.subtask);
+	    character = get_byte (&mixed.subtask);
+	    if (character != 's')
+	      break;
+	    put_byte ('s', &mixed.subtask);
+	    character = get_byte (&mixed.subtask);
+	    if (character != 't')
+	      break;
+	    put_byte ('t', &mixed.subtask);
+	    character = get_byte (&mixed.subtask);
+	    if (character != 'r')
+	      break;
+	    put_byte ('r', &mixed.subtask);
+	    character = get_byte (&mixed.subtask);
+
+	    msgstr = true;
+	    break;
+
+	  case '"':
+	    /* Copy the string, translating only the `msgstr' ones.  */
+
+	    put_byte ('"', &mixed.subtask);
+	    character = get_byte (&mixed.subtask);
+	    recode = msgstr;
+
+	    if (recode)
+	      start_accumulation (&mixed);
+
+	    while (true)
+	      {
 		if (character == EOF)
 		  {
 		    if (recode)
 		      {
 			recode_accumulated (&mixed);
-			status = false;
+			recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
 		      }
 		    break;
 		  }
+		if (character == '"')
+		  break;
+
+		if (character == '\\')
+		  {
+		    put_byte ('\\', &mixed.subtask);
+		    character = get_byte (&mixed.subtask);
+		    if (character == EOF)
+		      {
+			if (recode)
+			  {
+			    recode_accumulated (&mixed);
+			    recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
+			  }
+			break;
+		      }
+		  }
+		put_byte (character, &mixed.subtask);
+		character = get_byte (&mixed.subtask);
 	      }
+
+	    if (character == EOF)
+	      break;
+
+	    if (recode && !recode_accumulated (&mixed))
+	      recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
+
+	    put_byte ('"', &mixed.subtask);
+	    character = get_byte (&mixed.subtask);
+	    break;
+
+	  default:
 	    put_byte (character, &mixed.subtask);
 	    character = get_byte (&mixed.subtask);
+	    break;
 	  }
+    }
 
-	if (character == EOF)
-	  break;
-
-	if (recode)
-	  {
-	    if (!recode_accumulated (&mixed))
-	      status = false;
-	  }
-
-	put_byte ('"', &mixed.subtask);
-	character = get_byte (&mixed.subtask);
-	break;
-
-      default:
-	put_byte (character, &mixed.subtask);
-	character = get_byte (&mixed.subtask);
-	break;
-      }
-
-  close_mixed (&mixed);
-  return status;
+  if (!close_mixed (&mixed))
+    recode_if_nogo (RECODE_SYSTEM_ERROR, &mixed.subtask);
+  SUBTASK_RETURN (&mixed.subtask);
 }
