@@ -1,10 +1,10 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright  1990,92,93,94,96,97,98,99,00 Free Software Foundation, Inc.
-   Contributed by Franois Pinard <pinard@iro.umontreal.ca>, 1990.
+   Copyright © 1990,92,93,94,96,97,98,99,00 Free Software Foundation, Inc.
+   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1990.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
-   as published by the Free Software Foundation; either version 2 of the
+   as published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be
@@ -13,7 +13,7 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the `recode' Library; see the file `COPYING.LIB'.
+   License along with the Recode Library; see the file `COPYING.LIB'.
    If not, write to the Free Software Foundation, Inc., 59 Temple Place -
    Suite 330, Boston, MA 02111-1307, USA.  */
 
@@ -22,11 +22,11 @@
 
 /*-----------------------------------------------------------------------.
 | This dummy fallback routine is used to flag the intent of a reversible |
-| coding as a fallback, which is the traditional `recode' behaviour.     |
+| coding as a fallback, which is the traditional Recode behaviour.       |
 `-----------------------------------------------------------------------*/
 
-bool
-reversibility (RECODE_SUBTASK subtask, unsigned code)
+_GL_ATTRIBUTE_CONST bool
+reversibility (RECODE_SUBTASK subtask _GL_UNUSED_PARAMETER, unsigned code _GL_UNUSED_PARAMETER)
 {
   return false;
 }
@@ -68,6 +68,7 @@ declare_single (RECODE_OUTER outer,
 		Recode_init init_routine, Recode_transform transform_routine)
 {
   RECODE_SINGLE single = new_single_step (outer);
+  RECODE_ALIAS before = NULL, after = NULL;
 
   if (!single)
     return NULL;
@@ -75,59 +76,46 @@ declare_single (RECODE_OUTER outer,
   if (strcmp (before_name, "data") == 0)
     {
       single->before = outer->data_symbol;
-      single->after = find_alias (outer, after_name,
-				  SYMBOL_CREATE_DATA_SURFACE)->symbol;
+      after = find_alias (outer, after_name, SYMBOL_CREATE_DATA_SURFACE);
+      single->after = after->symbol;
     }
   else if (strcmp(after_name, "data") == 0)
     {
-      single->before = find_alias (outer, before_name,
-				   SYMBOL_CREATE_DATA_SURFACE)->symbol;
+      before = find_alias (outer, before_name, SYMBOL_CREATE_DATA_SURFACE);
+      single->before = before->symbol;
       single->after = outer->data_symbol;
     }
-  else if (strcmp (before_name, "tree") == 0)
-    {
-      single->before = outer->tree_symbol;
-      single->after = find_alias (outer, after_name,
-				  SYMBOL_CREATE_TREE_SURFACE)->symbol;
-    }
-  else if (strcmp(after_name, "tree") == 0)
-    {
-      single->before = find_alias (outer, before_name,
-				   SYMBOL_CREATE_TREE_SURFACE)->symbol;
-      single->after = outer->tree_symbol;
-    }
   else
     {
-      single->before = find_alias (outer, before_name,
-				   SYMBOL_CREATE_CHARSET)->symbol;
-      single->after = find_alias (outer, after_name,
-				  SYMBOL_CREATE_CHARSET)->symbol;
+      before = find_alias (outer, before_name, SYMBOL_CREATE_CHARSET);
+      single->before = before->symbol;
+      after = find_alias (outer, after_name, SYMBOL_CREATE_CHARSET);
+      single->after = after->symbol;
     }
 
-#if 0
-  /* FIXME: We should delink from the list of charsets before freeing.
-     The alias should also be freed. */
-  if (!before || !after)
+  if (!single->before || !single->after)
     {
-      free (single->before);
+      if (before)
+        delete_alias (before);
+      if (after)
+        delete_alias (after);
+      outer->single_list = single->next;
+      free (single);
       return NULL;
     }
-#endif
 
   single->quality = quality;
   single->init_routine = init_routine;
   single->transform_routine = transform_routine;
 
-  if (single->before == outer->data_symbol
-      || single->before == outer->tree_symbol)
+  if (single->before == outer->data_symbol)
     {
       if (single->after->resurfacer)
 	recode_error (outer, _("Resurfacer set more than once for `%s'"),
 		      after_name);
       single->after->resurfacer = single;
     }
-  else if (single->after == outer->data_symbol
-	   || single->after == outer->tree_symbol)
+  else if (single->after == outer->data_symbol)
     {
       if (single->before->unsurfacer)
 	recode_error (outer, _("Unsurfacer set more than once for `%s'"),
@@ -138,55 +126,22 @@ declare_single (RECODE_OUTER outer,
   return single;
 }
 
-#if 0
-
-/*-------------------------------------------.
-| Create and initialize a new data surface.  |
-`-------------------------------------------*/
-
-bool
-declare_data_surface (RECODE_OUTER outer, const char *name,
-		      struct recode_quality resurfacer_quality,
-		      Recode_init resurfacer_init_routine,
-		      Recode_transform resurfacer_transform_routine,
-		      struct recode_quality unsurfacer_quality,
-		      Recode_init unsurfacer_init_routine,
-		      Recode_transform unsurfacer_transform_routine)
-{
-}
-
-/*-------------------------------------------------.
-| Create and initialize a new structural surface.  |
-`-------------------------------------------------*/
-
-bool
-declare_tree_surface (RECODE_OUTER outer, const char *name,
-		      struct recode_quality resurfacer_quality,
-		      Recode_init resurfacer_init_routine,
-		      Recode_transform resurfacer_transform_routine,
-		      struct recode_quality unsurfacer_quality,
-		      Recode_init unsurfacer_init_routine,
-		      Recode_transform unsurfacer_transform_routine)
-{
-}
-
-#endif
-
-/*---------------------------------------------------------------------------.
-| Declare a charset available through `libiconv', given the NAME of this     |
-| charset (which might already exist as an alias).  Make two single steps in |
-| and out of it.                                                             |
-`---------------------------------------------------------------------------*/
+/*---------------------------------------------------------------.
+| Declare a charset available through `iconv', given the NAME of |
+| this charset (which might already exist as an alias), and the  |
+| ICONV_NAME to use when calling `iconv'.  Make two single steps |
+| in and out of it.                                              |
+`---------------------------------------------------------------*/
 
 static bool
 internal_iconv (RECODE_SUBTASK subtask)
 {
-  SET_SUBTASK_ERROR (RECODE_USER_ERROR, subtask);
+  recode_if_nogo (RECODE_USER_ERROR, subtask);
   SUBTASK_RETURN (subtask);
 }
 
 bool
-declare_libiconv (RECODE_OUTER outer, const char *name)
+declare_iconv (RECODE_OUTER outer, const char *name, const char *iconv_name)
 {
   RECODE_ALIAS alias;
   RECODE_SINGLE single;
@@ -198,17 +153,20 @@ declare_libiconv (RECODE_OUTER outer, const char *name)
       return false;
   assert(alias->symbol->type == RECODE_CHARSET);
 
+  if (!alias->symbol->iconv_name)
+    alias->symbol->iconv_name = iconv_name;
+
   if (single = new_single_step (outer), !single)
     return false;
   single->before = alias->symbol;
-  single->after = outer->libiconv_pivot;
+  single->after = outer->iconv_pivot;
   single->quality = outer->quality_variable_to_variable;
   single->init_routine = NULL;
   single->transform_routine = internal_iconv;
 
   if (single = new_single_step (outer), !single)
     return false;
-  single->before = outer->libiconv_pivot;
+  single->before = outer->iconv_pivot;
   single->after = alias->symbol;
   single->quality = outer->quality_variable_to_variable;
   single->init_routine = NULL;
@@ -217,34 +175,6 @@ declare_libiconv (RECODE_OUTER outer, const char *name)
   return true;
 }
 
-#if 0
-
-/*------------------------------------------------.
-| Save explode data within the symbol structure.  |
-`------------------------------------------------*/
-
-bool register_explode_data
-  PARAMS ((RECODE_OUTER, const char *, const unsigned short *));
-
-bool
-register_explode_data (RECODE_OUTER outer,
-		       const char *name, const unsigned short *data)
-{
-  RECODE_SYMBOL symbol;
-
-  symbol = find_alias (outer, name, SYMBOL_CREATE_CHARSET);
-  if (!symbol)
-    return false;
-
-  assert(symbol->type = RECODE_CHARSET);
-  symbol->data_type = RECODE_EXPLODE_DATA;
-  /* The cast is a way to silently discard the const.  */
-  symbol->data = (void *) data;
-  return true;
-}
-
-#endif
-
 /*--------------------------------------------------------------------------.
 | Associate an explode format DATA structure with charset NAME_COMBINED, an |
 | 8-bit charset.  A NULL value for NAME_EXPLODED implies UCS-2.  Otherwise, |
@@ -357,7 +287,7 @@ declare_strip_data (RECODE_OUTER outer, struct strip_data *data,
 `---------------------------------------------------------------*/
 
 static void
-estimate_single_cost (RECODE_OUTER outer, RECODE_SINGLE single)
+estimate_single_cost (RECODE_OUTER outer _GL_UNUSED_PARAMETER, RECODE_SINGLE single)
 {
   int cost;
 
@@ -376,7 +306,7 @@ estimate_single_cost (RECODE_OUTER outer, RECODE_SINGLE single)
       break;
 
     case RECODE_2:
-      /* Reading two require a routine call and swapping considerations.  */
+      /* Reading two requires a routine call and swapping considerations.  */
       cost += 25;
       break;
 
@@ -388,6 +318,9 @@ estimate_single_cost (RECODE_OUTER outer, RECODE_SINGLE single)
     case RECODE_N:
       /* Analysing varysizes is surely much harder than producing them.  */
       cost += 60;
+
+    default:
+      break;
     }
 
   switch (single->quality.out_size)
@@ -411,6 +344,9 @@ estimate_single_cost (RECODE_OUTER outer, RECODE_SINGLE single)
       /* Writing varysizes requires loops and such.  */
       cost += 35;
       break;
+
+    default:
+      break;
     }
 
   /* Consider speed for fine tuning the cost.  */
@@ -426,15 +362,13 @@ estimate_single_cost (RECODE_OUTER outer, RECODE_SINGLE single)
   return;
 }
 
-/*------------------------------------------------------------------------.
-| Initialize all collected single steps.  If STRICT_MAPPING is true, many |
-| recodings loose their reversibility.                                    |
-`------------------------------------------------------------------------*/
+/*----------------------------------------.
+| Initialize all collected single steps.  |
+`----------------------------------------*/
 
 #include "decsteps.h"
-bool module_libiconv PARAMS ((struct recode_outer *));
-void delmodule_libiconv PARAMS ((struct recode_outer *));
-
+bool module_iconv (struct recode_outer *);
+void delmodule_iconv (struct recode_outer *);
 
 static bool
 register_all_modules (RECODE_OUTER outer)
@@ -458,22 +392,21 @@ register_all_modules (RECODE_OUTER outer)
     return false;
   outer->data_symbol = alias->symbol;
 
-  if (alias = find_alias (outer, "tree", SYMBOL_CREATE_CHARSET), !alias)
-    return false;
-  outer->tree_symbol = alias->symbol;
-
   if (alias = find_alias (outer, "ISO-10646-UCS-2", SYMBOL_CREATE_CHARSET),
       !alias)
     return false;
   assert(alias->symbol->type == RECODE_CHARSET);
   outer->ucs2_charset = alias->symbol;
 
-  if (alias = find_alias (outer, ":libiconv:", SYMBOL_CREATE_CHARSET),
+  if (alias = find_alias (outer, ":iconv:", SYMBOL_CREATE_CHARSET),
       !alias)
     return false;
   assert(alias->symbol->type == RECODE_CHARSET);
-  outer->libiconv_pivot = alias->symbol;
-  if (!declare_alias (outer, ":", ":libiconv:"))
+  outer->iconv_pivot = alias->symbol;
+  if (!declare_alias (outer, ":", ":iconv:"))
+    return false;
+  /* Needed for compatibility with Recode 3.6.  */
+  if (!declare_alias (outer, ":libiconv:", ":iconv:"))
     return false;
 
   if (alias = find_alias (outer, "CR-LF", SYMBOL_CREATE_CHARSET), !alias)
@@ -486,20 +419,12 @@ register_all_modules (RECODE_OUTER outer)
   alias->symbol->type = RECODE_DATA_SURFACE;
   outer->cr_surface = alias->symbol;
 
-#if 0
-  /* `.' might be later used for asking recode to guess the charset.  */
-  if (!declare_alias (outer, ".", "RFC 1345"))
-    return false;
-#endif
   if (!declare_alias (outer, "ASCII", "ANSI_X3.4-1968"))
     return false;
   if (!declare_alias (outer, "BS", "ASCII-BS"))
     return false;
   if (!declare_alias (outer, "Latin-1", "ISO-8859-1"))
     return false;
-  /* Needed for compatibility with recode version 3.2.  */
-  if (!declare_alias (outer, "lat1", "Latin-1"))
-    return false;
 
 #include "inisteps.h"
 
@@ -507,8 +432,9 @@ register_all_modules (RECODE_OUTER outer)
      confusing some other initialisations that would come after it.  */
   if (!make_argmatch_arrays (outer))
     return false;
-  if (!module_libiconv (outer))
-    return false;
+  if (outer->use_iconv)
+    if (!module_iconv (outer))
+      return false;
 
   for (single = outer->single_list; single; single = single->next)
     estimate_single_cost (outer, single);
@@ -516,10 +442,12 @@ register_all_modules (RECODE_OUTER outer)
   return true;
 }
 
-void static
+static void
 unregister_all_modules (RECODE_OUTER outer)
 {
 #include "tersteps.h"
+  if (outer->use_iconv)
+    delmodule_iconv(outer);
 }
 
 /* Library interface.  */
@@ -532,20 +460,20 @@ unregister_all_modules (RECODE_OUTER outer)
 `-------------------------*/
 
 RECODE_OUTER
-recode_new_outer (bool auto_abort)
+recode_new_outer (unsigned flags)
 {
-  RECODE_OUTER outer = malloc (sizeof (struct recode_outer));
+  RECODE_OUTER outer = (RECODE_OUTER) calloc (1, sizeof (struct recode_outer));
 
   if (!outer)
     {
-      /* Diagnostic?  FIXME!  */
-      if (auto_abort)
+      recode_error (NULL, _("Virtual memory exhausted"));
+      if (flags & RECODE_AUTO_ABORT_FLAG)
 	exit (1);
       return NULL;
     }
 
-  memset (outer, 0, sizeof (struct recode_outer));
-  outer->auto_abort = auto_abort;
+  outer->auto_abort = (flags & RECODE_AUTO_ABORT_FLAG) != 0;
+  outer->use_iconv = (flags & RECODE_NO_ICONV_FLAG) == 0;
 
   if (!register_all_modules (outer) || !make_argmatch_arrays (outer))
     {
@@ -593,9 +521,6 @@ bool
 recode_delete_outer (RECODE_OUTER outer)
 {
   unregister_all_modules (outer);
-  /* FIXME: Pawel Krawczyk reports that calling new_outer ... delete_outer
-     20000 times in a program has the effect of consuming all virtual memory.
-     So there might be memory leaks should to track down and resolve.  */
   while (outer->number_of_symbols > 0)
     {
       RECODE_SYMBOL symbol = outer->symbol_list;
@@ -612,14 +537,20 @@ recode_delete_outer (RECODE_OUTER outer)
       outer->number_of_singles--;
       free (single);
     }
-  if (outer->pair_restriction)
-    free (outer->pair_restriction);
+  free (outer->pair_restriction);
   if (outer->alias_table)
-    hash_free (outer->alias_table);
+    hash_free ((Hash_table *) outer->alias_table);
   if (outer->argmatch_charset_array)
-    free (outer->argmatch_charset_array);
-  if (outer->one_to_same)
-    free ((void *) outer->one_to_same);
+    {
+      const char **cursor;
+
+      for (cursor = outer->argmatch_charset_array; *cursor; cursor++)
+        free ((char *) *cursor);
+      for (cursor = outer->argmatch_surface_array; *cursor; cursor++)
+        free ((char *) *cursor);
+      free (outer->argmatch_charset_array);
+    }
+  free ((void *) outer->one_to_same);
   free (outer);
   return true;
 }
