@@ -1,11 +1,11 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright  1997, 98, 99, 00 Free Software Foundation, Inc.
+   Copyright © 1997, 98, 99, 00 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
-   Contributed by Franois Pinard <pinard@iro.umontreal.ca>, 1997.
+   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1997.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
-   as published by the Free Software Foundation; either version 2 of the
+   as published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be
@@ -14,11 +14,12 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the `recode' Library; see the file `COPYING.LIB'.
+   License along with the Recode Library; see the file `COPYING.LIB'.
    If not, write to the Free Software Foundation, Inc., 59 Temple Place -
    Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "common.h"
+#include "decsteps.h"
 
 static bool
 permute_21 (RECODE_SUBTASK subtask)
@@ -112,7 +113,7 @@ module_permutations (RECODE_OUTER outer)
     && declare_alias (outer, "swabytes", "21-Permutation");
 }
 
-void
-delmodule_permutations (RECODE_OUTER outer)
+_GL_ATTRIBUTE_CONST void
+delmodule_permutations (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
