@@ -1,10 +1,10 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright  1996, 97, 98, 99, 00 Free Software Foundation, Inc.
-   Contributed by Franois Pinard <pinard@iro.umontreal.ca>, 1996.
+   Copyright © 1996, 97, 98, 99, 00 Free Software Foundation, Inc.
+   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1996.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
-   as published by the Free Software Foundation; either version 2 of the
+   as published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be
@@ -13,11 +13,12 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the `recode' Library; see the file `COPYING.LIB'.
+   License along with the Recode Library; see the file `COPYING.LIB'.
    If not, write to the Free Software Foundation, Inc., 59 Temple Place -
    Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "common.h"
+#include "decsteps.h"
 
 /* Description of some UCS-2 combinings.  */
 
@@ -388,14 +389,14 @@ get_ucs2 (unsigned *value, RECODE_SUBTASK subtask)
       character2 = get_byte (subtask);
       if (character2 == EOF)
 	{
-	  SET_SUBTASK_ERROR (RECODE_INVALID_INPUT, subtask);
+	  recode_if_nogo (RECODE_INVALID_INPUT, subtask);
 	  return false;
 	}
 
       switch (subtask->task->swap_input)
 	{
 	case RECODE_SWAP_UNDECIDED:
-	  chunk = ((MASK (8) & character1) << 8) | (MASK (8) & character2);
+	  chunk = ((BIT_MASK (8) & character1) << 8) | (BIT_MASK (8) & character2);
 	  switch (chunk)
 	    {
 	    case BYTE_ORDER_MARK:
@@ -416,7 +417,7 @@ get_ucs2 (unsigned *value, RECODE_SUBTASK subtask)
 	  break;
 
 	case RECODE_SWAP_NO:
-	  chunk = ((MASK (8) & character1) << 8) | (MASK (8) & character2);
+	  chunk = ((BIT_MASK (8) & character1) << 8) | (BIT_MASK (8) & character2);
 	  switch (chunk)
 	    {
 	    case BYTE_ORDER_MARK:
@@ -435,7 +436,7 @@ get_ucs2 (unsigned *value, RECODE_SUBTASK subtask)
 	  break;
 
 	case RECODE_SWAP_YES:
-	  chunk = ((MASK (8) & character2) << 8) | (MASK (8) & character1);
+	  chunk = ((BIT_MASK (8) & character2) << 8) | (BIT_MASK (8) & character1);
 	  switch (chunk)
 	    {
 	    case BYTE_ORDER_MARK:
@@ -452,6 +453,9 @@ get_ucs2 (unsigned *value, RECODE_SUBTASK subtask)
 	      return true;
 	    }
 	  break;
+
+        default:
+          break;
 	}
     }
 }
@@ -463,8 +467,8 @@ get_ucs2 (unsigned *value, RECODE_SUBTASK subtask)
 bool
 put_ucs2 (unsigned value, RECODE_SUBTASK subtask)
 {
-  put_byte (MASK (8) & value >> 8, subtask);
-  put_byte (MASK (8) & value, subtask);
+  put_byte (BIT_MASK (8) & value >> 8, subtask);
+  put_byte (BIT_MASK (8) & value, subtask);
   return true;
 }
 
@@ -483,31 +487,31 @@ get_ucs4 (unsigned *value, RECODE_SUBTASK subtask)
   character = get_byte (subtask);
   if (character == EOF)
     return false;
-  chunk = (MASK (8) & character) << 24;
+  chunk = (BIT_MASK (8) & character) << 24;
 
   character = get_byte (subtask);
   if (character == EOF)
     {
-      SET_SUBTASK_ERROR (RECODE_INVALID_INPUT, subtask);
+      recode_if_nogo (RECODE_INVALID_INPUT, subtask);
       return false;
     }
-  chunk |= (MASK (8) & character) << 16;
+  chunk |= (BIT_MASK (8) & character) << 16;
 
   character = get_byte (subtask);
   if (character == EOF)
     {
-      SET_SUBTASK_ERROR (RECODE_INVALID_INPUT, subtask);
+      recode_if_nogo (RECODE_INVALID_INPUT, subtask);
       return false;
     }
-  chunk |= (MASK (8) & character) << 8;
+  chunk |= (BIT_MASK (8) & character) << 8;
 
   character = get_byte (subtask);
   if (character == EOF)
     {
-      SET_SUBTASK_ERROR (RECODE_INVALID_INPUT, subtask);
+      recode_if_nogo (RECODE_INVALID_INPUT, subtask);
       return false;
     }
-  chunk |= MASK (8) & character;
+  chunk |= BIT_MASK (8) & character;
 
   *value = chunk;
   return true;
@@ -520,10 +524,10 @@ get_ucs4 (unsigned *value, RECODE_SUBTASK subtask)
 bool
 put_ucs4 (unsigned value, RECODE_SUBTASK subtask)
 {
-  put_byte (MASK (8) & value >> 24, subtask);
-  put_byte (MASK (8) & value >> 16, subtask);
-  put_byte (MASK (8) & value >> 8, subtask);
-  put_byte (MASK (8) & value, subtask);
+  put_byte (BIT_MASK (8) & value >> 24, subtask);
+  put_byte (BIT_MASK (8) & value >> 16, subtask);
+  put_byte (BIT_MASK (8) & value >> 8, subtask);
+  put_byte (BIT_MASK (8) & value, subtask);
   return true;
 }
 
@@ -565,7 +569,7 @@ transform_latin1_ucs4 (RECODE_SUBTASK subtask)
   int character;
 
   while (character = get_byte (subtask), character != EOF)
-    put_ucs4 (MASK (8) & character, subtask);
+    put_ucs4 (BIT_MASK (8) & character, subtask);
 
   SUBTASK_RETURN (subtask);
 }
@@ -621,7 +625,7 @@ module_ucs (RECODE_OUTER outer)
     && declare_alias (outer, "co", "combined-UCS-2");
 }
 
-void
-delmodule_ucs (RECODE_OUTER outer)
+_GL_ATTRIBUTE_CONST void
+delmodule_ucs (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
