@@ -1,10 +1,10 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright  1996, 97, 98, 99, 00 Free Software Foundation, Inc.
-   Contributed by Franois Pinard <pinard@iro.umontreal.ca>, 1996.
+   Copyright © 1996, 97, 98, 99, 00 Free Software Foundation, Inc.
+   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1996.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
-   as published by the Free Software Foundation; either version 2 of the
+   as published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be
@@ -13,11 +13,12 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the `recode' Library; see the file `COPYING.LIB'.
+   License along with the Recode Library; see the file `COPYING.LIB'.
    If not, write to the Free Software Foundation, Inc., 59 Temple Place -
    Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "common.h"
+#include "decsteps.h"
 
 static bool
 transform_ucs4_utf16 (RECODE_SUBTASK subtask)
@@ -31,14 +32,14 @@ transform_ucs4_utf16 (RECODE_SUBTASK subtask)
 
       while (true)
 	{
-	  if (value & ~MASK (16))
+	  if (value & ~BIT_MASK (16))
 	    if (value < (1 << 16 | 1 << 20))
 	      {
 		/* Double UCS-2 character.  */
 
 		value -= 1 << 16;
-		put_ucs2 (0xD800 | (MASK (10) & value >> 10), subtask);
-		put_ucs2 (0xDC00 | (MASK (10) & value), subtask);
+		put_ucs2 (0xD800 | (BIT_MASK (10) & value >> 10), subtask);
+		put_ucs2 (0xDC00 | (BIT_MASK (10) & value), subtask);
 	      }
 	    else
 	      {
@@ -210,7 +211,7 @@ module_utf16 (RECODE_OUTER outer)
     && declare_alias (outer, "u6", "UTF-16");
 }
 
-void
-delmodule_utf16 (RECODE_OUTER outer)
+_GL_ATTRIBUTE_CONST void
+delmodule_utf16 (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
