@@ -1,10 +1,10 @@
 /* Conversion of files between different charsets and surfaces.
-   Copyright  1996, 97, 98, 99, 00 Free Software Foundation, Inc.
-   Contributed by Franois Pinard <pinard@iro.umontreal.ca>, 1996.
+   Copyright © 1996, 97, 98, 99, 00 Free Software Foundation, Inc.
+   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1996.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
-   as published by the Free Software Foundation; either version 2 of the
+   as published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be
@@ -13,11 +13,12 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the `recode' Library; see the file `COPYING.LIB'.
+   License along with the Recode Library; see the file `COPYING.LIB'.
    If not, write to the Free Software Foundation, Inc., 59 Temple Place -
    Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "common.h"
+#include "decsteps.h"
 #include "base64.h"
 
 /* Classification of first 128 UCS-2 characters.  */
@@ -39,10 +40,6 @@ static char classification[128] =
 };
 #undef z
 
-/* Should the character be directly represented in message headers?  */
-#define IS_HEADER_DIRECT(Character) \
-  (IS_ASCII (Character) && classification[Character] & (D | W))
-
 /* Should the character be directly represented in message bodies?
    Here, & (D | O | W) is implied, since these are the only flags.  */
 #define IS_BODY_DIRECT(Character) \
@@ -99,9 +96,9 @@ transform_utf16_utf7 (RECODE_SUBTASK subtask)
 
 	    /* Process first UCS-2 value of a triplet.  */
 
-	    put_byte (base64_value_to_char[MASK (6) & value >> 10], subtask);
-	    put_byte (base64_value_to_char[MASK (6) & value >> 4], subtask);
-	    split = (value & MASK (4)) << 2;
+	    put_byte (base64_value_to_char[BIT_MASK (6) & value >> 10], subtask);
+	    put_byte (base64_value_to_char[BIT_MASK (6) & value >> 4], subtask);
+	    split = (value & BIT_MASK (4)) << 2;
 	    if (!get_ucs2 (&value, subtask))
 	      {
 		put_byte (base64_value_to_char[split], subtask);
@@ -115,11 +112,11 @@ transform_utf16_utf7 (RECODE_SUBTASK subtask)
 		put_byte (base64_value_to_char[split], subtask);
 		break;
 	      }
-	    put_byte (base64_value_to_char[split | (MASK (2) & value >> 14)],
+	    put_byte (base64_value_to_char[split | (BIT_MASK (2) & value >> 14)],
 		      subtask);
-	    put_byte (base64_value_to_char[MASK (6) & value >> 8], subtask);
-	    put_byte (base64_value_to_char[MASK (6) & value >> 2], subtask);
-	    split = (value & MASK (2)) << 4;
+	    put_byte (base64_value_to_char[BIT_MASK (6) & value >> 8], subtask);
+	    put_byte (base64_value_to_char[BIT_MASK (6) & value >> 2], subtask);
+	    split = (value & BIT_MASK (2)) << 4;
 	    if (!get_ucs2 (&value, subtask))
 	      {
 		put_byte (base64_value_to_char[split], subtask);
@@ -133,10 +130,10 @@ transform_utf16_utf7 (RECODE_SUBTASK subtask)
 		put_byte (base64_value_to_char[split], subtask);
 		break;
 	      }
-	    put_byte (base64_value_to_char[split | (MASK (4) & value >> 12)],
+	    put_byte (base64_value_to_char[split | (BIT_MASK (4) & value >> 12)],
 		      subtask);
-	    put_byte (base64_value_to_char[MASK (6) & value >> 6], subtask);
-	    put_byte (base64_value_to_char[MASK (6) & value], subtask);
+	    put_byte (base64_value_to_char[BIT_MASK (6) & value >> 6], subtask);
+	    put_byte (base64_value_to_char[BIT_MASK (6) & value], subtask);
 	    if (!get_ucs2 (&value, subtask))
 	      SUBTASK_RETURN (subtask);
 	  }
@@ -199,11 +196,11 @@ transform_utf7_utf16 (RECODE_SUBTASK subtask)
 
 	    if (!IS_BASE64 (character))
 	      {
-		if (MASK (2) & split)
+		if (BIT_MASK (2) & split)
 		  RETURN_IF_NOGO (RECODE_INVALID_INPUT, subtask);
 		break;
 	      }
-	    value = ((MASK (2) & split) << 14
+	    value = ((BIT_MASK (2) & split) << 14
 		     | base64_char_to_value[character] << 8);
 	    character = get_byte (subtask);
 
@@ -235,11 +232,11 @@ transform_utf7_utf16 (RECODE_SUBTASK subtask)
 
 	    if (!IS_BASE64 (character))
 	      {
-		if (MASK (4) & split)
+		if (BIT_MASK (4) & split)
 		  RETURN_IF_NOGO (RECODE_INVALID_INPUT, subtask);
 		break;
 	      }
-	    value = ((MASK (4) & split) << 12
+	    value = ((BIT_MASK (4) & split) << 12
 		     | base64_char_to_value[character] << 6);
 	    character = get_byte (subtask);
 
@@ -296,7 +293,7 @@ module_utf7 (RECODE_OUTER outer)
 		       NULL, transform_utf16_utf7);
 }
 
-void
-delmodule_utf7 (RECODE_OUTER outer)
+_GL_ATTRIBUTE_CONST void
+delmodule_utf7 (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
