@@ -4,7 +4,7 @@
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
-   as published by the Free Software Foundation; either version 2 of the
+   as published by the Free Software Foundation; either version 3 of the
    License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be
@@ -13,11 +13,12 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
-   License along with the `recode' Library; see the file `COPYING.LIB'.
+   License along with the Recode Library; see the file `COPYING.LIB'.
    If not, write to the Free Software Foundation, Inc., 59 Temple Place -
    Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "common.h"
+#include "decsteps.h"
 
 static const recode_ucs2 tcvn_pool[256] =
   {
@@ -454,7 +455,7 @@ module_vietnamese (RECODE_OUTER outer)
   return true;
 }
 
-void
-delmodule_vietnamese (RECODE_OUTER outer)
+_GL_ATTRIBUTE_CONST void
+delmodule_vietnamese (RECODE_OUTER outer _GL_UNUSED_PARAMETER)
 {
 }
